@@ -25,7 +25,7 @@ def load_pickled_list( local_root_directory= '../data/', list_pkl_file_name = 'm
         my_list = pickle.load(f)
     return my_list
 
-def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix=None, refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None):
+def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix=None, refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None,ssj_against='USDT', exchange = 'binance'):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
     pickle_saving_path = local_root_directory+ssj+'_'+dates_stub+daily_return_pkl_filename_suffix
     if refetch_all:
@@ -44,50 +44,50 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
         ts8 = ts7 - 2001 * 3600 * 24
 
         print('Loading data')
-
+        day_url_request = 'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym='+ssj_against+'&e='+exchange+'&toTs={}&limit=2000'
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts8))
+            day_url_request.format(ssj, ts8))
         dataframe = pd.DataFrame(json.loads(r.text)['Data'])
         #dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts7))
+            day_url_request.format(ssj, ts7))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts6))
+            day_url_request.format(ssj, ts6))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts5))
+            day_url_request.format(ssj, ts5))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts4))
+            day_url_request.format(ssj, ts4))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts3))
+            day_url_request.format(ssj, ts3))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts2))
+            day_url_request.format(ssj, ts2))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts1))
+            day_url_request.format(ssj, ts1))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts))
+            day_url_request.format(ssj, ts))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
 
@@ -107,7 +107,7 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
         dataframe = pd.read_pickle(pickle_saving_path)
     return dataframe
 
-def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_return_pkl_filename_suffix=None, running_date= None, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, refetch_all=True):
+def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_return_pkl_filename_suffix=None, running_date= None, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, refetch_all=True, ssj_against='USDT', exchange = 'binance'):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
     pickle_saving_path = local_root_directory+ssj+'_'+dates_stub+minutely_return_pkl_filename_suffix
     if refetch_all:
@@ -129,72 +129,73 @@ def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_ret
         ts11 = ts10 - 2001 * 60
         ts12 = ts11 - 2001 * 60
         print('Loading data')
+        binance_usdt_url = 'https://min-api.cryptocompare.com/data/v2/histominute?fsym={}&tsym='+ssj_against+'&e='+exchange+'&toTs={}&limit=2000'
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/v2/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts12))
+            binance_usdt_url.format(ssj, ts12))
         dataframe = pd.DataFrame(json.loads(r.text)['Data'])
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts11))
+            binance_usdt_url.format(ssj, ts11))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts10))
+            binance_usdt_url.format(ssj, ts10))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts9))
+            binance_usdt_url.format(ssj, ts9))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts8))
+            binance_usdt_url.format(ssj, ts8))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts7))
+            binance_usdt_url.format(ssj, ts7))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts6))
+            binance_usdt_url.format(ssj, ts6))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts5))
+            binance_usdt_url.format(ssj, ts5))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts4))
+            binance_usdt_url.format(ssj, ts4))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts3))
+            binance_usdt_url.format(ssj, ts3))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts2))
+            binance_usdt_url.format(ssj, ts2))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts1))
+            binance_usdt_url.format(ssj, ts1))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histominute?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts))
+            binance_usdt_url.format(ssj, ts))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
 
@@ -211,7 +212,7 @@ def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_ret
     return dataframe
 
 
-def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_pkl_filename_suffix=None,refetch_all=True, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None):
+def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_pkl_filename_suffix=None,refetch_all=True, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, ssj_against='USDT', exchange = 'binance'):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
     pickle_saving_path = local_root_directory + ssj + '_' + dates_stub + hourly_return_pkl_filename_suffix
     if refetch_all:
@@ -234,76 +235,77 @@ def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_
         ts12 = ts11 - 2001 * 3600
         ts13 = ts12 - 2001 * 3600
         print('Loading data')
+        hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&e=' + exchange + '&toTs={}&limit=2000'
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts13))
+            hours_url_request.format(ssj, ts13))
         dataframe = pd.DataFrame(json.loads(r.text)['Data'])
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts12))
+            hours_url_request.format(ssj, ts12))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts11))
+            hours_url_request.format(ssj, ts11))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts10))
+            hours_url_request.format(ssj, ts10))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts9))
+            hours_url_request.format(ssj, ts9))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts8))
+            hours_url_request.format(ssj, ts8))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts7))
+            hours_url_request.format(ssj, ts7))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts6))
+            hours_url_request.format(ssj, ts6))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         print('waiting')
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts5))
+            hours_url_request.format(ssj, ts5))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         time.sleep(1)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts4))
+            hours_url_request.format(ssj, ts4))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts3))
+            hours_url_request.format(ssj, ts3))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts2))
+            hours_url_request.format(ssj, ts2))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts1))
+            hours_url_request.format(ssj, ts1))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
         r = requests.get(
-            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts))
+            hours_url_request.format(ssj, ts))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
 
