@@ -49,7 +49,7 @@ class AbstractRunner(ABC):
 
 class  ForecasterRunner(AbstractRunner):
     def runTrial(self, saver, seed, n, s, s_eval, calibration_step, signal_type, idios_string):
-        continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo = saver.create_saving_key(seed, n, s, s_eval, calibration_step, signal_type, idios_string)
+        continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo , idios= saver.create_saving_key(seed, n, s, s_eval, calibration_step, signal_type, idios_string)
         check_run_existence, table_number = saver.checkRunExistence(continuous_saving_key)
         exhaustive_check_run_existence, exhaustive_table_number = saver.exhaustiveCheckRunExistence(continuous_saving_key)
         assert check_run_existence == exhaustive_check_run_existence
@@ -84,7 +84,7 @@ class  ForecasterRunner(AbstractRunner):
         print('output shape')
         print(y.shape)
         chosen_method = signal_type
-        model = forecasting_utility.instantiate_model(method=chosen_method)
+        model = forecasting_utility.instantiate_model(method=chosen_method, idios = idios)
 
         # Compute rolling weights
         forecasted_series, features_importances, discrete_two_states_forecasting_series, discrete_two_states_forecasting_series_lo, discrete_three_states_forecasting_series, discrete_three_states_forecasting_series_lo = time_series.rolling_forecasting(
