@@ -19,7 +19,7 @@ class AbstractRunner(ABC):
         self.underlying = underlying
         self.local_root_directory=local_root_directory
         self.dates_stub = starting_date.strftime('%d_%b_%Y') + '_' + running_date.strftime('%d_%b_%Y')
-        self.saving_return_path = self.local_root_directory+self.underlying+ '_' + self.dates_stub + '_' + self.freqly_pkl_file_name_suffix
+        self.saving_return_path = self.local_root_directory+self.underlying+ '_' + self.dates_stub + self.freqly_pkl_file_name_suffix
         self.user=user
         self.dropbox_backup = dropbox_backup
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
