@@ -572,6 +572,35 @@ class RealTimeSignalEnsemblingParalleLauncher():
         print('saving histo recomputation to '+backed_up_signal_histo_name)
         cumulated_signals.to_pickle(saving_path)
 
+
+    def reload_minute_histo(self, from_cryptocompare = True, nb_last_hours=24):
+        if not from_cryptocompare :
+            raise Exception('not implemented yet')
+        running_date = datetime.now()
+        starting_date = running_date - timedelta(hours = nb_last_hours)
+        freqly_pkl_file_name_suffix = '_min_tmp.pkl'
+        mins_df = napoleon_connector.fetch_crypto_minutely_data(ssj=self.underlying, local_root_directory=self.local_root_directory,
+                                                               minutely_return_pkl_filename_suffix=freqly_pkl_file_name_suffix,
+                                                               daily_crypto_starting_day=starting_date,
+                                                               daily_crypto_ending_day=running_date,
+                                                               refetch_all=True)
+        return mins_df
+
+
+    def reload_hour_histo(self, from_cryptocompare=False, nb_last_days = 1):
+        if not from_cryptocompare:
+            raise Exception('not implemented yet')
+        running_date = datetime.now()
+        starting_date = running_date - timedelta(days=nb_last_days)
+        freqly_pkl_file_name_suffix = '_day_tmp.pkl'
+        hours_df = napoleon_connector.fetch_crypto_minutely_data(ssj=self.underlying,
+                                                                 local_root_directory=self.local_root_directory,
+                                                                 minutely_return_pkl_filename_suffix=freqly_pkl_file_name_suffix,
+                                                                 daily_crypto_starting_day=starting_date,
+                                                                 daily_crypto_ending_day=running_date,
+                                                                 refetch_all=True)
+        return hours_df
+
     def reload_daily_histo(self, from_cryptocompare = False):
         upto_date = datetime.now() - timedelta(days=1)
         if from_cryptocompare :
